Body class

Inheritance

Constructors

Body(dynamic $image, [double $w = 20, double $h = 0])

Properties

h double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image Span?
getter/setter pair
name String
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
w double
getter/setter pair

Methods

init(PBody emitter, PBody particle) → dynamic
inherited
initialize(PBody particle) → dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSpanValue(dynamic image) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited